import axios from 'axios';
import store from '../store/store';
import * as types from '../store/types';
import router from '../router';
import {Message} from 'element-ui';

export const domin = '/api'  //本地环境
// export const domin = ''   //生产环境
//axios配置
let instance = axios.create({
    baseURL:'/api', //本地环境
    // baseURL:'http://172.19.1.232:8085',  //生产环境
    // timeout:20000,
});

//http request 拦截器
instance.interceptors.request.use(
    config => {
        if (store.state.token) {
            config.headers.Authorization = `token ${store.state.token}`
        }
        return config;
    },
    error => {
        return Promise.reject(err);
    }
);

//http reponse拦截器
instance.interceptors.response.use(
    response => {
        if (response.data.code !== 0) {
            // Message.error(response.data.message)
        }
        return response.data;  //只返回服务器返回的data信息
    },
    error => {
        if (error.response) {
            switch (error.response.status) {
                case 401:
                    // Message.error("没有权限")
                    store.commit(types.LOGOUt);
                    router.currentRoute.path !== 'login' &&
                    router.replace({
                        path: 'login',
                        query: {redirect: router.currentRoute.path},
                    });
                    break;
                case 404:
                    // Message.error("请求路径错误")
                    break;
                case 500:
                    // Message.error('系统错误')
                    break;
            }
        }
        return Promise.reject(error.response.data);
    },
);

/**
 * method  请求的方法：get、post、delete、put
 * url 请求的url；
 * data  请求的参数
 * @return {Promise}  返回一个promise的对象，相当于axios请求数据的返回值
 */
export default function (method, url, data = null) {
    method = method.toLowerCase();
    if (method === 'post') {
        return instance.post(url, data);
    } else if (method === 'get') {
        return instance.get(url, {params: data})
    } else if (method === 'delete') {
        return instance.delete(url, {params: data})
    } else if (method === 'put') {
        return instance.put(url, data);
    } else {
        console.error("未知的method" + method);
        return false;
    }
}
